<div align="center">

# KIVI

[![Python package](https://img.shields.io/pypi/v/kivi)](https://pypi.org/project/kivi/)
[![Python](https://img.shields.io/pypi/pyversions/kivi.svg)](https://pypi.python.org/pypi/kivi/)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/kivi)](https://pypi.org/project/kivi/)
[![GitHub star chart](https://img.shields.io/github/stars/kivi-risk/kivi?style=flat-square)](https://star-history.com/#kivi-risk/kivi)
[![GitHub Forks](https://img.shields.io/github/forks/kivi-risk/kivi.svg)](https://star-history.com/#kivi-risk/kivi)
[![Doc](https://img.shields.io/badge/Doc-online-green)](https://kivi-risk.github.io/kivi-doc/)
[![Issue](https://img.shields.io/github/issues/kivi-risk/kivi)](https://github.com/kivi-risk/kivi/issues/new/choose)
[![Discussions](https://img.shields.io/github/discussions/kivi-risk/kivi)](https://github.com/kivi-risk/kivi/issues/new/choose)
[![CONTRIBUTING](https://img.shields.io/badge/Contributing-8A2BE2)](https://github.com/kivi-risk/kivi/blob/main/CONTRIBUTING.md)
[![License: MIT](https://img.shields.io/github/license/kivi-risk/kivi)](https://github.com/kivi-risk/kivi/blob/main/LICENSE)

> 一款自动化风控建模工具集

</div>

## 简介

[详细文档](https://kivi-risk.github.io/kivi-doc/)

-----

## 如何安装？

```bash
# [推荐] 安装最新版本ZLAI的所有模块
pip install kivi[all] -U
# [补充] 增加了一些 nlp 内容
pip install kivi[jieba] -U
# [补充] 增加了一些 pyspark 内容
pip install kivi[pyspark] -U
```

您也可以在[GitHub](https://github.com/kivi-risk/kivi.git)/[PyPi](https://pypi.org/project/kivi/)查看最新代码与最新发行版本。

## Star History

[![Star History Chart](https://api.star-history.com/svg?repos=kivi-risk/kivi&type=Date)](https://star-history.com/#kivi-risk/kivi&Date)

-----

> Wechat

<center>
<img src="https://raw.githubusercontent.com/zlai-llm/zlai/master/assets/wechat.jpg" width="160px">
<h5>微信群</h5>
</center>

-----
@2024/03/27
